@@ -9,6 +9,7 @@ from .stream_client import StreamClient
 from .api_client import APIClient
 from .user_client import UserClient
 from ..exceptions.UnauthorizedException import UnauthorizedException
+from json.decoder import JSONDecodeError
 
 # SymBotClient class is the Client class that has access to all of the other
 # client classes upon initialization, SymBotClient class gets an instance of
@@ -75,32 +76,33 @@ class SymBotClient(APIClient):
     def get_pod_session(self):
         if self.pod_session is None:
             self.pod_session = requests.Session()
-            self.pod_session.headers.update({'sessionToken' : self.auth.get_session_token()})
+            self.pod_session.headers.update({
+                'sessionToken': self.auth.get_session_token()}
+            )
             self.pod_session.proxies.update(self.config.data['podProxyRequestObject'])
-            if (self.config.data['truststorePath']):
-                logging.debug("Setting trusstorePath for pod to {}".format(self.config.data['truststorePath']))
-                self.pod_session.verify=self.config.data['truststorePath']
-
+            if self.config.data['truststorePath']:
+                logging.debug("Setting trustorePath for pod to {}".format(
+                    self.config.data['truststorePath']))
+                self.pod_session.verify = self.config.data['truststorePath']
         return self.pod_session
 
     def get_agent_session(self):
         if self.agent_session is None:
             self.agent_session = requests.Session()
-            self.agent_session.headers.update(
-                {'sessionToken' : self.auth.get_session_token(), 
-                'keyManagerToken': self.auth.get_key_manager_token()
-                })
-
+            self.agent_session.headers.update({
+                'sessionToken': self.auth.get_session_token(),
+                'keyManagerToken': self.auth.get_key_manager_token()}
+            )
             self.agent_session.proxies.update(self.config.data['agentProxyRequestObject'])
-            if (self.config.data['truststorePath']):
-                logging.debug("Setting trusstorePath for agent to {}".format(self.config.data['truststorePath']))
+            if self.config.data['truststorePath']:
+                logging.debug("Setting trustorePath for agent to {}".format(
+                    self.config.data['truststorePath'])
+                )
                 self.agent_session.verify=self.config.data['truststorePath']
-
         return self.agent_session
     
     def execute_rest_call(self, method, path, **kwargs):
         results = None
-        url = None
         session = None
         if path.startswith("/agent/"):
             url = self.config.data["agentHost"] + path
@@ -115,7 +117,10 @@ class SymBotClient(APIClient):
         if response.status_code == 204:
             results = []
         elif response.status_code == 200:
-            results = json.loads(response.text)
+            try:
+                results = json.loads(response.text)
+            except JSONDecodeError:
+                results = response.text
         else:
             try:
                 super().handle_error(response, self)
@@ -125,15 +130,17 @@ class SymBotClient(APIClient):
 
     def reauth_client(self):
         self.auth.authenticate()
-        if (self.pod_session is not None):
-            self.pod_session.headers.update({'sessionToken' : self.auth.get_session_token()})
-        if (self.agent_session is not None):
-            self.agent_session.headers.update(
-                {'sessionToken' : self.auth.get_session_token(), 
-                'keyManagerToken': self.auth.get_key_manager_token()
-                })
+        if self.pod_session:
+            self.pod_session.headers.update({
+                'sessionToken': self.auth.get_session_token()}
+            )
+        if self.agent_session:
+            self.agent_session.headers.update({
+                'sessionToken' : self.auth.get_session_token(),
+                'keyManagerToken': self.auth.get_key_manager_token()}
+            )
 
     def get_bot_user_info(self):
-        if (self.bot_user_info is None):
+        if self.bot_user_info is None:
             self.bot_user_info = self.get_user_client().get_session_user()
         return self.bot_user_info
